import sys
import ctypes
class LCDPixelState:
	# Pixel off state
	PIXEL_STATE_OFF = 0
	# Pixel on state
	PIXEL_STATE_ON = 1
	# Invert the pixel state
	PIXEL_STATE_INVERT = 2

	@classmethod
	def getName(self, val):
		if val == self.PIXEL_STATE_OFF:
			return "PIXEL_STATE_OFF"
		if val == self.PIXEL_STATE_ON:
			return "PIXEL_STATE_ON"
		if val == self.PIXEL_STATE_INVERT:
			return "PIXEL_STATE_INVERT"
		return "<invalid enumeration value>"



import sys
import ctypes
class PowerSupply:
	# Switch the sensor power supply off
	POWER_SUPPLY_OFF = 1
	# The sensor is provided with 12 volts
	POWER_SUPPLY_12V = 2
	# The sensor is provided with 24 volts
	POWER_SUPPLY_24V = 3

	@classmethod
	def getName(self, val):
		if val == self.POWER_SUPPLY_OFF:
			return "POWER_SUPPLY_OFF"
		if val == self.POWER_SUPPLY_12V:
			return "POWER_SUPPLY_12V"
		if val == self.POWER_SUPPLY_24V:
			return "POWER_SUPPLY_24V"
		return "<invalid enumeration value>"



import sys
import ctypes
class LEDForwardVoltage:
	# 1.7 V
	LED_FORWARD_VOLTAGE_1_7V = 1
	# 2.75 V
	LED_FORWARD_VOLTAGE_2_75V = 2
	# 3.2 V
	LED_FORWARD_VOLTAGE_3_2V = 3
	# 3.9 V
	LED_FORWARD_VOLTAGE_3_9V = 4
	# 4.0 V
	LED_FORWARD_VOLTAGE_4_0V = 5
	# 4.8 V
	LED_FORWARD_VOLTAGE_4_8V = 6
	# 5.0 V
	LED_FORWARD_VOLTAGE_5_0V = 7
	# 5.6 V
	LED_FORWARD_VOLTAGE_5_6V = 8

	@classmethod
	def getName(self, val):
		if val == self.LED_FORWARD_VOLTAGE_1_7V:
			return "LED_FORWARD_VOLTAGE_1_7V"
		if val == self.LED_FORWARD_VOLTAGE_2_75V:
			return "LED_FORWARD_VOLTAGE_2_75V"
		if val == self.LED_FORWARD_VOLTAGE_3_2V:
			return "LED_FORWARD_VOLTAGE_3_2V"
		if val == self.LED_FORWARD_VOLTAGE_3_9V:
			return "LED_FORWARD_VOLTAGE_3_9V"
		if val == self.LED_FORWARD_VOLTAGE_4_0V:
			return "LED_FORWARD_VOLTAGE_4_0V"
		if val == self.LED_FORWARD_VOLTAGE_4_8V:
			return "LED_FORWARD_VOLTAGE_4_8V"
		if val == self.LED_FORWARD_VOLTAGE_5_0V:
			return "LED_FORWARD_VOLTAGE_5_0V"
		if val == self.LED_FORWARD_VOLTAGE_5_6V:
			return "LED_FORWARD_VOLTAGE_5_6V"
		return "<invalid enumeration value>"



import sys
import ctypes
class LCDScreenSize:
	# Screen size unknown
	SCREEN_SIZE_NONE = 1
	# One row, eight column text screen
	SCREEN_SIZE_1x8 = 2
	# Two row, eight column text screen
	SCREEN_SIZE_2x8 = 3
	# One row, 16 column text screen
	SCREEN_SIZE_1x16 = 4
	# Two row, 16 column text screen
	SCREEN_SIZE_2x16 = 5
	# Four row, 16 column text screen
	SCREEN_SIZE_4x16 = 6
	# Two row, 20 column text screen
	SCREEN_SIZE_2x20 = 7
	# Four row, 20 column text screen.
	SCREEN_SIZE_4x20 = 8
	# Two row, 24 column text screen
	SCREEN_SIZE_2x24 = 9
	# One row, 40 column text screen
	SCREEN_SIZE_1x40 = 10
	# Two row, 40 column text screen
	SCREEN_SIZE_2x40 = 11
	# Four row, 40 column text screen
	SCREEN_SIZE_4x40 = 12
	# 64px by 128px graphic screen
	SCREEN_SIZE_64x128 = 13

	@classmethod
	def getName(self, val):
		if val == self.SCREEN_SIZE_NONE:
			return "SCREEN_SIZE_NONE"
		if val == self.SCREEN_SIZE_1x8:
			return "SCREEN_SIZE_1x8"
		if val == self.SCREEN_SIZE_2x8:
			return "SCREEN_SIZE_2x8"
		if val == self.SCREEN_SIZE_1x16:
			return "SCREEN_SIZE_1x16"
		if val == self.SCREEN_SIZE_2x16:
			return "SCREEN_SIZE_2x16"
		if val == self.SCREEN_SIZE_4x16:
			return "SCREEN_SIZE_4x16"
		if val == self.SCREEN_SIZE_2x20:
			return "SCREEN_SIZE_2x20"
		if val == self.SCREEN_SIZE_4x20:
			return "SCREEN_SIZE_4x20"
		if val == self.SCREEN_SIZE_2x24:
			return "SCREEN_SIZE_2x24"
		if val == self.SCREEN_SIZE_1x40:
			return "SCREEN_SIZE_1x40"
		if val == self.SCREEN_SIZE_2x40:
			return "SCREEN_SIZE_2x40"
		if val == self.SCREEN_SIZE_4x40:
			return "SCREEN_SIZE_4x40"
		if val == self.SCREEN_SIZE_64x128:
			return "SCREEN_SIZE_64x128"
		return "<invalid enumeration value>"



import sys
import ctypes
class DataAdapterStopBits:
	# One Stop Bit
	STOP_BITS_ONE = 1
	# Two Stop Bits
	STOP_BITS_TWO = 2

	@classmethod
	def getName(self, val):
		if val == self.STOP_BITS_ONE:
			return "STOP_BITS_ONE"
		if val == self.STOP_BITS_TWO:
			return "STOP_BITS_TWO"
		return "<invalid enumeration value>"



import sys
import ctypes

from Phidget22.PhidgetServerType import PhidgetServerType

class PhidgetServer(ctypes.Structure):
	_fields_ = [
		("_name", ctypes.c_char_p),
		("_stype", ctypes.c_char_p),
		("_type", ctypes.c_int),
		("_flags", ctypes.c_int),
		("_addr", ctypes.c_char_p),
		("_host", ctypes.c_char_p),
		("_port", ctypes.c_int),
	]

	def __init__(self):
		self.name = ""
		self.stype = ""
		self.type = 0
		self.flags = 0
		self.addr = ""
		self.host = ""
		self.port = 0

	def fromPython(self):
		self._name = self.name.encode('utf-8')
		self._stype = self.stype.encode('utf-8')
		self._type = self.type
		self._flags = self.flags
		self._addr = self.addr.encode('utf-8')
		self._host = self.host.encode('utf-8')
		self._port = self.port
		return self

	def toPython(self):
		if self._name == None:
			self.name = None
		else:
			self.name = self._name.decode('utf-8')
		if self._stype == None:
			self.stype = None
		else:
			self.stype = self._stype.decode('utf-8')
		if self._type == None:
			self.type = None
		else:
			self.type = self._type
		if self._flags == None:
			self.flags = None
		else:
			self.flags = self._flags
		if self._addr == None:
			self.addr = None
		else:
			self.addr = self._addr.decode('utf-8')
		if self._host == None:
			self.host = None
		else:
			self.host = self._host.decode('utf-8')
		if self._port == None:
			self.port = None
		else:
			self.port = self._port
		return self

	def __str__(self):
		return ("[PhidgetServer] ("
			"name: " + str(self.name) + ", "
			"stype: " + str(self.stype) + ", "
			"type: " + str(self.type) + ", "
			"flags: " + str(self.flags) + ", "
			"addr: " + str(self.addr) + ", "
			"host: " + str(self.host) + ", "
			"port: " + str(self.port) + 
			")")



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.ErrorCode import ErrorCode

class PhidgetException(Exception):

	def __init__(self,code):

		_code = ctypes.c_int()
		_desc = ctypes.c_char_p()
		_detailLen = ctypes.c_size_t()

		result = PhidgetSupport.getDll().Phidget_getLastError(ctypes.byref(_code), ctypes.byref(_desc), None, ctypes.byref(_detailLen))
		if result == 0 and _code.value == code:
			_detail = ctypes.create_string_buffer(_detailLen.value)
			result = PhidgetSupport.getDll().Phidget_getLastError(ctypes.byref(_code), ctypes.byref(_desc), _detail, ctypes.byref(_detailLen))
			if result == 0:
				self.code = _code.value
				self.details = _detail.value.decode("utf-8");
				self.description = _desc.value.decode("utf-8");
				return

		result = PhidgetSupport.getDll().Phidget_getErrorDescription(_code, ctypes.byref(_desc))

		if result == 0:
			self.code = code
			self.details = ""
			self.description = _desc.value.decode("utf-8");
			return

		self.code = code
		self.details = ""
		self.description = "";

	def __str__(self):
		return "PhidgetException 0x%02x (%s)\n%s" % (self.code, self.description, self.details)

	def __del__(self):
		pass



import sys
import ctypes
class EncoderIOMode:
	# No additional pull-up or pull-down resistors will be applied to the input lines.
	ENCODER_IO_MODE_PUSH_PULL = 1
	# 2.2kΩ pull-down resistors will be applied to the input lines.
	ENCODER_IO_MODE_LINE_DRIVER_2K2 = 2
	# 10kΩ pull-down resistors will be applied to the input lines.
	ENCODER_IO_MODE_LINE_DRIVER_10K = 3
	# 2.2kΩ pull-up resistors will be applied to the input lines.
	ENCODER_IO_MODE_OPEN_COLLECTOR_2K2 = 4
	# 10kΩ pull-up resistors will be applied to the input lines.
	ENCODER_IO_MODE_OPEN_COLLECTOR_10K = 5

	@classmethod
	def getName(self, val):
		if val == self.ENCODER_IO_MODE_PUSH_PULL:
			return "ENCODER_IO_MODE_PUSH_PULL"
		if val == self.ENCODER_IO_MODE_LINE_DRIVER_2K2:
			return "ENCODER_IO_MODE_LINE_DRIVER_2K2"
		if val == self.ENCODER_IO_MODE_LINE_DRIVER_10K:
			return "ENCODER_IO_MODE_LINE_DRIVER_10K"
		if val == self.ENCODER_IO_MODE_OPEN_COLLECTOR_2K2:
			return "ENCODER_IO_MODE_OPEN_COLLECTOR_2K2"
		if val == self.ENCODER_IO_MODE_OPEN_COLLECTOR_10K:
			return "ENCODER_IO_MODE_OPEN_COLLECTOR_10K"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class CapacitiveTouch(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._TouchFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._TouchFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._Touch = None
		self._onTouch = None

		if sys.platform == 'win32':
			self._TouchEndFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._TouchEndFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		self._TouchEnd = None
		self._onTouchEnd = None

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localTouchEvent(self, handle, userPtr, touchValue):
		if self._Touch == None:
			return
		self._Touch(self, touchValue)

	def setOnTouchHandler(self, handler):
		if handler == None:
			self._Touch = None
			self._onTouch = None
		else:
			self._Touch = handler
			self._onTouch = self._TouchFactory(self._localTouchEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setOnTouchHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTouch, None)
		except RuntimeError:
			self._Touch = None
			self._onTouch = None

	def _localTouchEndEvent(self, handle, userPtr):
		if self._TouchEnd == None:
			return
		self._TouchEnd(self)

	def setOnTouchEndHandler(self, handler):
		if handler == None:
			self._TouchEnd = None
			self._onTouchEnd = None
		else:
			self._TouchEnd = handler
			self._onTouchEnd = self._TouchEndFactory(self._localTouchEndEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setOnTouchEndHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTouchEnd, None)
		except RuntimeError:
			self._TouchEnd = None
			self._onTouchEnd = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getIsTouched(self):
		_IsTouched = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getIsTouched
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsTouched))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsTouched.value)

	def getSensitivity(self):
		_Sensitivity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getSensitivity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Sensitivity))

		if result > 0:
			raise PhidgetException(result)

		return _Sensitivity.value

	def setSensitivity(self, Sensitivity):
		_Sensitivity = ctypes.c_double(Sensitivity)

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setSensitivity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Sensitivity)

		if result > 0:
			raise PhidgetException(result)


	def getMinSensitivity(self):
		_MinSensitivity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMinSensitivity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinSensitivity))

		if result > 0:
			raise PhidgetException(result)

		return _MinSensitivity.value

	def getMaxSensitivity(self):
		_MaxSensitivity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMaxSensitivity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxSensitivity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxSensitivity.value

	def getTouchValue(self):
		_TouchValue = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getTouchValue
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TouchValue))

		if result > 0:
			raise PhidgetException(result)

		return _TouchValue.value

	def getMinTouchValue(self):
		_MinTouchValue = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMinTouchValue
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinTouchValue))

		if result > 0:
			raise PhidgetException(result)

		return _MinTouchValue.value

	def getMaxTouchValue(self):
		_MaxTouchValue = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMaxTouchValue
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxTouchValue))

		if result > 0:
			raise PhidgetException(result)

		return _MaxTouchValue.value

	def getTouchValueChangeTrigger(self):
		_TouchValueChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getTouchValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TouchValueChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _TouchValueChangeTrigger.value

	def setTouchValueChangeTrigger(self, TouchValueChangeTrigger):
		_TouchValueChangeTrigger = ctypes.c_double(TouchValueChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_setTouchValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TouchValueChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinTouchValueChangeTrigger(self):
		_MinTouchValueChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMinTouchValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinTouchValueChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinTouchValueChangeTrigger.value

	def getMaxTouchValueChangeTrigger(self):
		_MaxTouchValueChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCapacitiveTouch_getMaxTouchValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxTouchValueChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxTouchValueChangeTrigger.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class PressureSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._PressureChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PressureChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PressureChange = None
		self._onPressureChange = None

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localPressureChangeEvent(self, handle, userPtr, pressure):
		if self._PressureChange == None:
			return
		self._PressureChange(self, pressure)

	def setOnPressureChangeHandler(self, handler):
		if handler == None:
			self._PressureChange = None
			self._onPressureChange = None
		else:
			self._PressureChange = handler
			self._onPressureChange = self._PressureChangeFactory(self._localPressureChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetPressureSensor_setOnPressureChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPressureChange, None)
		except RuntimeError:
			self._PressureChange = None
			self._onPressureChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getPressure(self):
		_Pressure = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getPressure
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Pressure))

		if result > 0:
			raise PhidgetException(result)

		return _Pressure.value

	def getMinPressure(self):
		_MinPressure = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMinPressure
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPressure))

		if result > 0:
			raise PhidgetException(result)

		return _MinPressure.value

	def getMaxPressure(self):
		_MaxPressure = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMaxPressure
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPressure))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPressure.value

	def getPressureChangeTrigger(self):
		_PressureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getPressureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PressureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _PressureChangeTrigger.value

	def setPressureChangeTrigger(self, PressureChangeTrigger):
		_PressureChangeTrigger = ctypes.c_double(PressureChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_setPressureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PressureChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinPressureChangeTrigger(self):
		_MinPressureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMinPressureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPressureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinPressureChangeTrigger.value

	def getMaxPressureChangeTrigger(self):
		_MaxPressureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPressureSensor_getMaxPressureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPressureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPressureChangeTrigger.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.FanMode import FanMode
from Phidget22.EncoderIOMode import EncoderIOMode
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class MotorPositionController(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setTargetPosition_async = None
		self._onsetTargetPosition_async = None

		if sys.platform == 'win32':
			self._DutyCycleUpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._DutyCycleUpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._DutyCycleUpdate = None
		self._onDutyCycleUpdate = None

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PositionChange = None
		self._onPositionChange = None

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localDutyCycleUpdateEvent(self, handle, userPtr, dutyCycle):
		if self._DutyCycleUpdate == None:
			return
		self._DutyCycleUpdate(self, dutyCycle)

	def setOnDutyCycleUpdateHandler(self, handler):
		if handler == None:
			self._DutyCycleUpdate = None
			self._onDutyCycleUpdate = None
		else:
			self._DutyCycleUpdate = handler
			self._onDutyCycleUpdate = self._DutyCycleUpdateFactory(self._localDutyCycleUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setOnDutyCycleUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onDutyCycleUpdate, None)
		except RuntimeError:
			self._DutyCycleUpdate = None
			self._onDutyCycleUpdate = None

	def _localPositionChangeEvent(self, handle, userPtr, position):
		if self._PositionChange == None:
			return
		self._PositionChange(self, position)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def getAcceleration(self):
		_Acceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return _Acceleration.value

	def setAcceleration(self, Acceleration):
		_Acceleration = ctypes.c_double(Acceleration)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Acceleration)

		if result > 0:
			raise PhidgetException(result)


	def getMinAcceleration(self):
		_MinAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MinAcceleration.value

	def getMaxAcceleration(self):
		_MaxAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAcceleration.value

	def getCurrentLimit(self):
		_CurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentLimit.value

	def setCurrentLimit(self, CurrentLimit):
		_CurrentLimit = ctypes.c_double(CurrentLimit)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentLimit(self):
		_MinCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentLimit.value

	def getMaxCurrentLimit(self):
		_MaxCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentLimit.value

	def getCurrentRegulatorGain(self):
		_CurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentRegulatorGain.value

	def setCurrentRegulatorGain(self, CurrentRegulatorGain):
		_CurrentRegulatorGain = ctypes.c_double(CurrentRegulatorGain)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentRegulatorGain)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentRegulatorGain(self):
		_MinCurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentRegulatorGain.value

	def getMaxCurrentRegulatorGain(self):
		_MaxCurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentRegulatorGain.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getDeadBand(self):
		_DeadBand = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getDeadBand
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeadBand))

		if result > 0:
			raise PhidgetException(result)

		return _DeadBand.value

	def setDeadBand(self, DeadBand):
		_DeadBand = ctypes.c_double(DeadBand)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setDeadBand
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DeadBand)

		if result > 0:
			raise PhidgetException(result)


	def getDutyCycle(self):
		_DutyCycle = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getDutyCycle
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DutyCycle))

		if result > 0:
			raise PhidgetException(result)

		return _DutyCycle.value

	def getEngaged(self):
		_Engaged = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Engaged))

		if result > 0:
			raise PhidgetException(result)

		return bool(_Engaged.value)

	def setEngaged(self, Engaged):
		_Engaged = ctypes.c_int(Engaged)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Engaged)

		if result > 0:
			raise PhidgetException(result)


	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getFanMode(self):
		_FanMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FanMode))

		if result > 0:
			raise PhidgetException(result)

		return _FanMode.value

	def setFanMode(self, FanMode):
		_FanMode = ctypes.c_int(FanMode)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FanMode)

		if result > 0:
			raise PhidgetException(result)


	def getIOMode(self):
		_IOMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getIOMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IOMode))

		if result > 0:
			raise PhidgetException(result)

		return _IOMode.value

	def setIOMode(self, IOMode):
		_IOMode = ctypes.c_int(IOMode)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setIOMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IOMode)

		if result > 0:
			raise PhidgetException(result)


	def getKd(self):
		_Kd = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getKd
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Kd))

		if result > 0:
			raise PhidgetException(result)

		return _Kd.value

	def setKd(self, Kd):
		_Kd = ctypes.c_double(Kd)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setKd
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Kd)

		if result > 0:
			raise PhidgetException(result)


	def getKi(self):
		_Ki = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getKi
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Ki))

		if result > 0:
			raise PhidgetException(result)

		return _Ki.value

	def setKi(self, Ki):
		_Ki = ctypes.c_double(Ki)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setKi
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Ki)

		if result > 0:
			raise PhidgetException(result)


	def getKp(self):
		_Kp = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getKp
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Kp))

		if result > 0:
			raise PhidgetException(result)

		return _Kp.value

	def setKp(self, Kp):
		_Kp = ctypes.c_double(Kp)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setKp
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Kp)

		if result > 0:
			raise PhidgetException(result)


	def getPosition(self):
		_Position = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Position))

		if result > 0:
			raise PhidgetException(result)

		return _Position.value

	def getMinPosition(self):
		_MinPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MinPosition.value

	def getMaxPosition(self):
		_MaxPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPosition.value

	def addPositionOffset(self, positionOffset):
		_positionOffset = ctypes.c_double(positionOffset)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_addPositionOffset
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _positionOffset)

		if result > 0:
			raise PhidgetException(result)


	def getRescaleFactor(self):
		_RescaleFactor = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RescaleFactor))

		if result > 0:
			raise PhidgetException(result)

		return _RescaleFactor.value

	def setRescaleFactor(self, RescaleFactor):
		_RescaleFactor = ctypes.c_double(RescaleFactor)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RescaleFactor)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getStallVelocity(self):
		_StallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_StallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _StallVelocity.value

	def setStallVelocity(self, StallVelocity):
		_StallVelocity = ctypes.c_double(StallVelocity)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _StallVelocity)

		if result > 0:
			raise PhidgetException(result)


	def getMinStallVelocity(self):
		_MinStallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinStallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MinStallVelocity.value

	def getMaxStallVelocity(self):
		_MaxStallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxStallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxStallVelocity.value

	def getTargetPosition(self):
		_TargetPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetPosition))

		if result > 0:
			raise PhidgetException(result)

		return _TargetPosition.value

	def setTargetPosition(self, TargetPosition):
		_TargetPosition = ctypes.c_double(TargetPosition)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetPosition)

		if result > 0:
			raise PhidgetException(result)


	def setTargetPosition_async(self, TargetPosition, asyncHandler):
		_TargetPosition = ctypes.c_double(TargetPosition)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setTargetPosition_async
		__func(self.handle, _TargetPosition, _asyncHandler, _ctx)


	def getVelocityLimit(self):
		_VelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _VelocityLimit.value

	def setVelocityLimit(self, VelocityLimit):
		_VelocityLimit = ctypes.c_double(VelocityLimit)

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_setVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VelocityLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinVelocityLimit(self):
		_MinVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMinVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinVelocityLimit.value

	def getMaxVelocityLimit(self):
		_MaxVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMotorPositionController_getMaxVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVelocityLimit.value



import sys
import ctypes
class BridgeGain:
	# 1x Amplificaion
	BRIDGE_GAIN_1 = 1
	# 2x Amplification
	BRIDGE_GAIN_2 = 2
	# 4x Amplification
	BRIDGE_GAIN_4 = 3
	# 8x Amplification
	BRIDGE_GAIN_8 = 4
	# 16x Amplification
	BRIDGE_GAIN_16 = 5
	# 32x Amplification
	BRIDGE_GAIN_32 = 6
	# 64x Amplification
	BRIDGE_GAIN_64 = 7
	# 128x Amplification
	BRIDGE_GAIN_128 = 8

	@classmethod
	def getName(self, val):
		if val == self.BRIDGE_GAIN_1:
			return "BRIDGE_GAIN_1"
		if val == self.BRIDGE_GAIN_2:
			return "BRIDGE_GAIN_2"
		if val == self.BRIDGE_GAIN_4:
			return "BRIDGE_GAIN_4"
		if val == self.BRIDGE_GAIN_8:
			return "BRIDGE_GAIN_8"
		if val == self.BRIDGE_GAIN_16:
			return "BRIDGE_GAIN_16"
		if val == self.BRIDGE_GAIN_32:
			return "BRIDGE_GAIN_32"
		if val == self.BRIDGE_GAIN_64:
			return "BRIDGE_GAIN_64"
		if val == self.BRIDGE_GAIN_128:
			return "BRIDGE_GAIN_128"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.GPSDate import GPSDate
from Phidget22.GPSTime import GPSTime
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class GPS(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._HeadingChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double)
		else:
			self._HeadingChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double)
		self._HeadingChange = None
		self._onHeadingChange = None

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double)
		self._PositionChange = None
		self._onPositionChange = None

		if sys.platform == 'win32':
			self._PositionFixStateChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)
		else:
			self._PositionFixStateChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)
		self._PositionFixStateChange = None
		self._onPositionFixStateChange = None

		__func = PhidgetSupport.getDll().PhidgetGPS_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localHeadingChangeEvent(self, handle, userPtr, heading, velocity):
		if self._HeadingChange == None:
			return
		self._HeadingChange(self, heading, velocity)

	def setOnHeadingChangeHandler(self, handler):
		if handler == None:
			self._HeadingChange = None
			self._onHeadingChange = None
		else:
			self._HeadingChange = handler
			self._onHeadingChange = self._HeadingChangeFactory(self._localHeadingChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetGPS_setOnHeadingChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onHeadingChange, None)
		except RuntimeError:
			self._HeadingChange = None
			self._onHeadingChange = None

	def _localPositionChangeEvent(self, handle, userPtr, latitude, longitude, altitude):
		if self._PositionChange == None:
			return
		self._PositionChange(self, latitude, longitude, altitude)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetGPS_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def _localPositionFixStateChangeEvent(self, handle, userPtr, positionFixState):
		if self._PositionFixStateChange == None:
			return
		self._PositionFixStateChange(self, positionFixState)

	def setOnPositionFixStateChangeHandler(self, handler):
		if handler == None:
			self._PositionFixStateChange = None
			self._onPositionFixStateChange = None
		else:
			self._PositionFixStateChange = handler
			self._onPositionFixStateChange = self._PositionFixStateChangeFactory(self._localPositionFixStateChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetGPS_setOnPositionFixStateChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionFixStateChange, None)
		except RuntimeError:
			self._PositionFixStateChange = None
			self._onPositionFixStateChange = None

	def getAltitude(self):
		_Altitude = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGPS_getAltitude
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Altitude))

		if result > 0:
			raise PhidgetException(result)

		return _Altitude.value

	def getDate(self):
		_Date = GPSDate()

		__func = PhidgetSupport.getDll().PhidgetGPS_getDate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Date))

		if result > 0:
			raise PhidgetException(result)

		return _Date.toPython()

	def getHeading(self):
		_Heading = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGPS_getHeading
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Heading))

		if result > 0:
			raise PhidgetException(result)

		return _Heading.value

	def getLatitude(self):
		_Latitude = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGPS_getLatitude
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Latitude))

		if result > 0:
			raise PhidgetException(result)

		return _Latitude.value

	def getLongitude(self):
		_Longitude = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGPS_getLongitude
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Longitude))

		if result > 0:
			raise PhidgetException(result)

		return _Longitude.value

	def getPositionFixState(self):
		_PositionFixState = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetGPS_getPositionFixState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PositionFixState))

		if result > 0:
			raise PhidgetException(result)

		return bool(_PositionFixState.value)

	def getTime(self):
		_Time = GPSTime()

		__func = PhidgetSupport.getDll().PhidgetGPS_getTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Time))

		if result > 0:
			raise PhidgetException(result)

		return _Time.toPython()

	def getVelocity(self):
		_Velocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGPS_getVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Velocity))

		if result > 0:
			raise PhidgetException(result)

		return _Velocity.value



import sys
import ctypes
class RTDType:
	# Configures the RTD type as a PT100 with a 3850ppm curve.
	RTD_TYPE_PT100_3850 = 1
	# Configures the RTD type as a PT1000 with a 3850ppm curve.
	RTD_TYPE_PT1000_3850 = 2
	# Configures the RTD type as a PT100 with a 3920ppm curve.
	RTD_TYPE_PT100_3920 = 3
	# Configures the RTD type as a PT1000 with a 3920ppm curve.
	RTD_TYPE_PT1000_3920 = 4

	@classmethod
	def getName(self, val):
		if val == self.RTD_TYPE_PT100_3850:
			return "RTD_TYPE_PT100_3850"
		if val == self.RTD_TYPE_PT1000_3850:
			return "RTD_TYPE_PT1000_3850"
		if val == self.RTD_TYPE_PT100_3920:
			return "RTD_TYPE_PT100_3920"
		if val == self.RTD_TYPE_PT1000_3920:
			return "RTD_TYPE_PT1000_3920"
		return "<invalid enumeration value>"



import sys
import ctypes


class SpatialQuaternion(ctypes.Structure):
	_fields_ = [
		("_x", ctypes.c_double),
		("_y", ctypes.c_double),
		("_z", ctypes.c_double),
		("_w", ctypes.c_double),
	]

	def __init__(self):
		self.x = 0
		self.y = 0
		self.z = 0
		self.w = 0

	def fromPython(self):
		self._x = self.x
		self._y = self.y
		self._z = self.z
		self._w = self.w
		return self

	def toPython(self):
		if self._x == None:
			self.x = None
		else:
			self.x = self._x
		if self._y == None:
			self.y = None
		else:
			self.y = self._y
		if self._z == None:
			self.z = None
		else:
			self.z = self._z
		if self._w == None:
			self.w = None
		else:
			self.w = self._w
		return self

	def __str__(self):
		return ("[SpatialQuaternion] ("
			"x: " + str(self.x) + ", "
			"y: " + str(self.y) + ", "
			"z: " + str(self.z) + ", "
			"w: " + str(self.w) + 
			")")



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.LogLevel import LogLevel
from Phidget22.PhidgetException import PhidgetException

class Log:

	def __init__(self):
		self.handle = ctypes.c_void_p()


	def __del__(self):
			pass

	@staticmethod
	def disable():
		__func = PhidgetSupport.getDll().PhidgetLog_disable
		__func.restype = ctypes.c_int32
		result = __func()

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def enable(level, destination):
		_level = ctypes.c_int(level)
		_destination = ctypes.create_string_buffer(destination.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetLog_enable
		__func.restype = ctypes.c_int32
		result = __func(_level, ctypes.byref(_destination))

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def getLevel():
		_level = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLog_getLevel
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_level))

		if result > 0:
			raise PhidgetException(result)

		return _level.value

	@staticmethod
	def setLevel(level):
		_level = ctypes.c_int(level)

		__func = PhidgetSupport.getDll().PhidgetLog_setLevel
		__func.restype = ctypes.c_int32
		result = __func(_level)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def log(level, message):
		_level = ctypes.c_int(level)
		_message = ctypes.create_string_buffer(message.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetLog_log
		__func.restype = ctypes.c_int32
		result = __func(_level, ctypes.byref(_message))

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def rotate():
		__func = PhidgetSupport.getDll().PhidgetLog_rotate
		__func.restype = ctypes.c_int32
		result = __func()

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def isRotating():
		_isrotating = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLog_isRotating
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_isrotating))

		if result > 0:
			raise PhidgetException(result)

		return bool(_isrotating.value)

	@staticmethod
	def getRotating():
		_size = ctypes.c_uint64()
		_keepCount = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLog_getRotating
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_size), ctypes.byref(_keepCount))

		if result > 0:
			raise PhidgetException(result)

		return _size.value, _keepCount.value

	@staticmethod
	def setRotating(size, keepCount):
		_size = ctypes.c_uint64(size)
		_keepCount = ctypes.c_int(keepCount)

		__func = PhidgetSupport.getDll().PhidgetLog_setRotating
		__func.restype = ctypes.c_int32
		result = __func(_size, _keepCount)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def enableRotating():
		__func = PhidgetSupport.getDll().PhidgetLog_enableRotating
		__func.restype = ctypes.c_int32
		result = __func()

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def disableRotating():
		__func = PhidgetSupport.getDll().PhidgetLog_disableRotating
		__func.restype = ctypes.c_int32
		result = __func()

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def getSourceLevel(source):
		_source = ctypes.create_string_buffer(source.encode('utf-8'))
		_level = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLog_getSourceLevel
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_source), ctypes.byref(_level))

		if result > 0:
			raise PhidgetException(result)

		return _level.value

	@staticmethod
	def setSourceLevel(source, level):
		_source = ctypes.create_string_buffer(source.encode('utf-8'))
		_level = ctypes.c_int(level)

		__func = PhidgetSupport.getDll().PhidgetLog_setSourceLevel
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_source), _level)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class DeviceClass:
	# PhidgetAccelerometer device
	PHIDCLASS_ACCELEROMETER = 1
	# PhidgetAdvancedServo device
	PHIDCLASS_ADVANCEDSERVO = 2
	# PhidgetAnalog device
	PHIDCLASS_ANALOG = 3
	# PhidgetBridge device
	PHIDCLASS_BRIDGE = 4
	# Dictionary device
	PHIDCLASS_DICTIONARY = 24
	# PhidgetEncoder device
	PHIDCLASS_ENCODER = 5
	# PhidgetFrequencyCounter device
	PHIDCLASS_FREQUENCYCOUNTER = 6
	# PhidgetGPS device
	PHIDCLASS_GPS = 7
	# Phidget VINT Hub device
	PHIDCLASS_HUB = 8
	# PhidgetInterfaceKit device
	PHIDCLASS_INTERFACEKIT = 9
	# PhidgetIR device
	PHIDCLASS_IR = 10
	# PhidgetLED device
	PHIDCLASS_LED = 11
	# PhidgetMotorControl device
	PHIDCLASS_MOTORCONTROL = 13
	# PhidgetPHSensor device
	PHIDCLASS_PHSENSOR = 14
	# PhidgetRFID device
	PHIDCLASS_RFID = 15
	# PhidgetServo device
	PHIDCLASS_SERVO = 16
	# PhidgetSpatial device
	PHIDCLASS_SPATIAL = 17
	# PhidgetStepper device
	PHIDCLASS_STEPPER = 18
	# PhidgetTemperatureSensor device
	PHIDCLASS_TEMPERATURESENSOR = 19
	# PhidgetTextLCD device
	PHIDCLASS_TEXTLCD = 20
	# Phidget VINT device
	PHIDCLASS_VINT = 21

	@classmethod
	def getName(self, val):
		if val == self.PHIDCLASS_ACCELEROMETER:
			return "PHIDCLASS_ACCELEROMETER"
		if val == self.PHIDCLASS_ADVANCEDSERVO:
			return "PHIDCLASS_ADVANCEDSERVO"
		if val == self.PHIDCLASS_ANALOG:
			return "PHIDCLASS_ANALOG"
		if val == self.PHIDCLASS_BRIDGE:
			return "PHIDCLASS_BRIDGE"
		if val == self.PHIDCLASS_DICTIONARY:
			return "PHIDCLASS_DICTIONARY"
		if val == self.PHIDCLASS_ENCODER:
			return "PHIDCLASS_ENCODER"
		if val == self.PHIDCLASS_FREQUENCYCOUNTER:
			return "PHIDCLASS_FREQUENCYCOUNTER"
		if val == self.PHIDCLASS_GPS:
			return "PHIDCLASS_GPS"
		if val == self.PHIDCLASS_HUB:
			return "PHIDCLASS_HUB"
		if val == self.PHIDCLASS_INTERFACEKIT:
			return "PHIDCLASS_INTERFACEKIT"
		if val == self.PHIDCLASS_IR:
			return "PHIDCLASS_IR"
		if val == self.PHIDCLASS_LED:
			return "PHIDCLASS_LED"
		if val == self.PHIDCLASS_MOTORCONTROL:
			return "PHIDCLASS_MOTORCONTROL"
		if val == self.PHIDCLASS_PHSENSOR:
			return "PHIDCLASS_PHSENSOR"
		if val == self.PHIDCLASS_RFID:
			return "PHIDCLASS_RFID"
		if val == self.PHIDCLASS_SERVO:
			return "PHIDCLASS_SERVO"
		if val == self.PHIDCLASS_SPATIAL:
			return "PHIDCLASS_SPATIAL"
		if val == self.PHIDCLASS_STEPPER:
			return "PHIDCLASS_STEPPER"
		if val == self.PHIDCLASS_TEMPERATURESENSOR:
			return "PHIDCLASS_TEMPERATURESENSOR"
		if val == self.PHIDCLASS_TEXTLCD:
			return "PHIDCLASS_TEXTLCD"
		if val == self.PHIDCLASS_VINT:
			return "PHIDCLASS_VINT"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Hub(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		__func = PhidgetSupport.getDll().PhidgetHub_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def getPortPower(self, port):
		_port = ctypes.c_int(port)
		_state = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetHub_getPortPower
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _port, ctypes.byref(_state))

		if result > 0:
			raise PhidgetException(result)

		return bool(_state.value)

	def setPortPower(self, port, state):
		_port = ctypes.c_int(port)
		_state = ctypes.c_int(state)

		__func = PhidgetSupport.getDll().PhidgetHub_setPortPower
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _port, _state)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class FilterType:
	# Frequency is calculated from the number of times the signal transitions from a negative voltage to a positive voltage and back again.
	FILTER_TYPE_ZERO_CROSSING = 1
	# Frequency is calculated from the number of times the signal transitions from a logic false to a logic true and back again.
	FILTER_TYPE_LOGIC_LEVEL = 2

	@classmethod
	def getName(self, val):
		if val == self.FILTER_TYPE_ZERO_CROSSING:
			return "FILTER_TYPE_ZERO_CROSSING"
		if val == self.FILTER_TYPE_LOGIC_LEVEL:
			return "FILTER_TYPE_LOGIC_LEVEL"
		return "<invalid enumeration value>"



import sys
import ctypes
class Unit:
	# Unitless
	PHIDUNIT_NONE = 0
	# Boolean
	PHIDUNIT_BOOLEAN = 1
	# Percent
	PHIDUNIT_PERCENT = 2
	# Decibel
	PHIDUNIT_DECIBEL = 3
	# Millimeter
	PHIDUNIT_MILLIMETER = 4
	# Centimeter
	PHIDUNIT_CENTIMETER = 5
	# Meter
	PHIDUNIT_METER = 6
	# Gram
	PHIDUNIT_GRAM = 7
	# Kilogram
	PHIDUNIT_KILOGRAM = 8
	# Milliampere
	PHIDUNIT_MILLIAMPERE = 9
	# Ampere
	PHIDUNIT_AMPERE = 10
	# Kilopascal
	PHIDUNIT_KILOPASCAL = 11
	# Volt
	PHIDUNIT_VOLT = 12
	# Degree Celcius
	PHIDUNIT_DEGREE_CELCIUS = 13
	# Lux
	PHIDUNIT_LUX = 14
	# Gauss
	PHIDUNIT_GAUSS = 15
	# pH
	PHIDUNIT_PH = 16
	# Watt
	PHIDUNIT_WATT = 17

	@classmethod
	def getName(self, val):
		if val == self.PHIDUNIT_NONE:
			return "PHIDUNIT_NONE"
		if val == self.PHIDUNIT_BOOLEAN:
			return "PHIDUNIT_BOOLEAN"
		if val == self.PHIDUNIT_PERCENT:
			return "PHIDUNIT_PERCENT"
		if val == self.PHIDUNIT_DECIBEL:
			return "PHIDUNIT_DECIBEL"
		if val == self.PHIDUNIT_MILLIMETER:
			return "PHIDUNIT_MILLIMETER"
		if val == self.PHIDUNIT_CENTIMETER:
			return "PHIDUNIT_CENTIMETER"
		if val == self.PHIDUNIT_METER:
			return "PHIDUNIT_METER"
		if val == self.PHIDUNIT_GRAM:
			return "PHIDUNIT_GRAM"
		if val == self.PHIDUNIT_KILOGRAM:
			return "PHIDUNIT_KILOGRAM"
		if val == self.PHIDUNIT_MILLIAMPERE:
			return "PHIDUNIT_MILLIAMPERE"
		if val == self.PHIDUNIT_AMPERE:
			return "PHIDUNIT_AMPERE"
		if val == self.PHIDUNIT_KILOPASCAL:
			return "PHIDUNIT_KILOPASCAL"
		if val == self.PHIDUNIT_VOLT:
			return "PHIDUNIT_VOLT"
		if val == self.PHIDUNIT_DEGREE_CELCIUS:
			return "PHIDUNIT_DEGREE_CELCIUS"
		if val == self.PHIDUNIT_LUX:
			return "PHIDUNIT_LUX"
		if val == self.PHIDUNIT_GAUSS:
			return "PHIDUNIT_GAUSS"
		if val == self.PHIDUNIT_PH:
			return "PHIDUNIT_PH"
		if val == self.PHIDUNIT_WATT:
			return "PHIDUNIT_WATT"
		return "<invalid enumeration value>"
